@@ -1,4 +1,6 @@
-use clap::Clap;
+#![warn(clippy::pedantic, clippy::nursery)]
+
+use clap::Parser;
 use lcat::{Rainbow, RainbowCmd};
 use std::{
     fs::File,
@@ -6,11 +8,7 @@ use std::{
     path::PathBuf,
 };
 
-#[cfg(feature = "mimalloc")]
-#[global_allocator]
-static GLOBAL: mimalloc::MiMalloc = mimalloc::MiMalloc;
-
-#[derive(Clap)]
+#[derive(Parser)]
 #[clap(name = "lcat", about = "Terminal rainbows.")]
 pub struct Cmdline {
     #[clap(name = "File", default_value = "-", parse(from_os_str))]
